@@ -128,6 +128,7 @@ case 'delete':
 <?php
 	$go_delete = false;
 	foreach ( (array) $userids as $id ) {
+		$id = (int) $id;
 		$user = new WP_User($id);
 		if ( $id == $current_user->ID ) {
 			echo "<li>" . sprintf(__('ID #%1s: %2s <strong>The current user will not be deleted.</strong>'), $id, $user->user_login) . "</li>\n";
@@ -145,13 +146,13 @@ case 'delete':
 	?>
 	</ul>
 <?php if ( $go_delete ) : ?>
-	<p><?php _e('What should be done with posts and links owned by this user?'); ?></p>
+	<fieldset><p><legend><?php _e('What should be done with posts and links owned by this user?'); ?></legend></p>
 	<ul style="list-style:none;">
 		<li><label><input type="radio" id="delete_option0" name="delete_option" value="delete" checked="checked" />
 		<?php _e('Delete all posts and links.'); ?></label></li>
 		<li><input type="radio" id="delete_option1" name="delete_option" value="reassign" />
 		<?php echo '<label for="delete_option1">'.__('Attribute all posts and links to:')."</label> $user_dropdown"; ?></li>
-	</ul>
+	</ul></fieldset>
 	<input type="hidden" name="action" value="dodelete" />
 	<p class="submit"><input type="submit" name="submit" value="<?php _e('Confirm Deletion'); ?>" class="button-secondary" /></p>
 <?php else : ?>
@@ -181,7 +182,7 @@ case 'doremove':
 			$update = 'err_admin_remove';
 			continue;
 		}
-		remove_user_from_blog($id);
+		remove_user_from_blog($id, $blog_id);
 	}
 
 	wp_redirect('users.php?update=' . $update);
@@ -264,8 +265,9 @@ case 'addexistinguser':
 			if( ($username != null && is_site_admin( $username ) == false ) && ( array_key_exists($blog_id, get_blogs_of_user($user_id)) ) ) {
 				$location = 'users.php?update=add_existing';
 			} else {
-				add_user_to_blog('', $user_id, $_REQUEST[ 'new_role' ]);
-				do_action( "added_existing_user", $user_id );
+				$newuser_key = substr( md5( $user_id ), 0, 5 );
+				add_option( 'new_user_' . $newuser_key, array( 'user_id' => $user_id, 'email' => $user->user_email, 'role' => $_REQUEST[ 'new_role' ] ) );
+				wp_mail( $new_user_email, sprintf( __( '[%s] Joining confirmation' ), get_option( 'blogname' ) ), "Hi,\n\nYou have been invited to join '" . get_option( 'blogname' ) . "' at\n" . site_url() . "\nPlease click the following link to confirm the invite:\n" . site_url( "/newbloguser/$newuser_key/" ) );
 				$location = 'users.php?update=add';
 			}
 			wp_redirect("$location");
@@ -412,6 +414,7 @@ unset($role_links);
 ?>
 </ul>
 	<p id="post-search">
+	<label class="hidden" for="post-search-input"><?php _e( 'Search Users' ); ?>:</label>
 	<input type="text" id="post-search-input" name="usersearch" value="<?php echo attribute_escape($wp_user_search->search_term); ?>" />
 	<input type="submit" value="<?php _e( 'Search Users' ); ?>" class="button" />
 	</p>
@@ -424,7 +427,7 @@ unset($role_links);
 
 <div class="alignleft">
 <input type="submit" value="<?php _e('Remove'); ?>" name="removeit" class="button-secondary delete" />
-<select name="new_role"><option value=''><?php _e('Change role to&hellip;') ?></option>"<?php wp_dropdown_roles(); ?></select>
+<label class="hidden" for="new_role"><?php _e('Change role to&hellip;') ?></label><select name="new_role" id="new_role"><option value=''><?php _e('Change role to&hellip;') ?></option>"<?php wp_dropdown_roles(); ?></select>
 <input type="submit" value="<?php _e('Change'); ?>" name="changeit" class="button-secondary" />
 <?php wp_nonce_field('bulk-users'); ?>
 </div>
@@ -455,7 +458,7 @@ unset($role_links);
 <table class="widefat">
 <thead>
 <tr class="thead">
-	<th scope="col" class="check-column"><input type="checkbox" onclick="checkAll(document.getElementById('posts-filter'));" /> </th>
+	<th scope="col" class="check-column"><input type="checkbox" /></th>
 	<th><?php _e('Username') ?></th>
 	<th><?php _e('Name') ?></th>
 	<th><?php _e('E-mail') ?></th>
@@ -487,9 +490,9 @@ foreach ( $wp_user_search->get_results() as $userid ) {
 <br class="clear" />
 </div>
 
-</form>
 <?php endif; ?>
 
+</form>
 </div>
 
 <?php
@@ -503,6 +506,7 @@ foreach ( $wp_user_search->get_results() as $userid ) {
 ?>
 
 <br class="clear" />
+<?php if ( current_user_can('create_users') ) { ?>
 
 <?php if( apply_filters('show_adduser_fields', true) ) {?>
 <div class="wrap">
@@ -511,7 +515,7 @@ foreach ( $wp_user_search->get_results() as $userid ) {
 <form action="" method="post" name="adduser" id="adduser">
 <?php wp_nonce_field('add-user') ?>
 <input type='hidden' name='action' value='addexistinguser'>
-<p><?php _e('Type the e-mail address of another user to add them to your blog.')?></p>
+<p><?php _e('Type the e-mail address of another user to add them to your blog. They will be sent a confirmation email with a link to click before they are added.')?></p>
 
 <table class="form-table">
 	<tr class="form-field form-required">
@@ -529,7 +533,7 @@ foreach ( $wp_user_search->get_results() as $userid ) {
 </table>
 <p class="submit">
 	<?php echo $referer; ?>
-	<input name="adduser" type="submit" id="addusersub" value="<?php _e('Add User &raquo;') ?>" />
+	<input name="adduser" type="submit" id="addusersub" value="<?php _e('Add User') ?>" />
 </p>
 </form>
 </div>
@@ -547,6 +551,7 @@ foreach ( $wp_user_search->get_results() as $userid ) {
 </div>
 
 <?php
+}
 break;
 
 } // end of the $action switch
